@@ -26,7 +26,7 @@ def fetch_live_option_candle(redis_cursor, symbol, strike_price, option_type):
         poc_result = redis_cursor.get(key_symbol)
         if not poc_result:
             return None
-        option_candle = json.loads(poc_result)
+        option_candle = json.loads(poc_result)[key_name]
         print(f"option_candle : {option_candle}")
 
         option_candle["close"] = option_candle["last_price"]
