@@ -127,7 +127,7 @@ def save_lt_order(app_db_cursor, redis_cursor, orders_list, tradingsymbol, quant
                       "position_type": position_type,
                       "template_id": 0
                       }
-
+        print(f"Alert Dict : {alert_dict}")
         send_order_alert(alert_dict)
 
         orders_list = fetch_orders_list(redis_cursor=redis_cursor, request_id=str(request_id))
@@ -156,10 +156,10 @@ def place_live_order(credential_id, order_details):
     try:
         print("Placing Live Trade Order")
         request_dict = {"credential_id": str(credential_id),
-                        "order_details": json.dumps(order_details)}
+                        "order_params": json.dumps(order_details)}
         print(f"request_dict : {request_dict}")
 
-        response = requests.post(url=orders_url+"place_order", params=request_dict)
+        response = requests.post(url=orders_url+"place_order", json=request_dict)
         print("******** Order Placement Response *********")
         print(response.json())
         return response.json()
@@ -173,10 +173,10 @@ def modify_live_order(credential_id, order_details):
     try:
         print("* Modifying Live Order")
         request_dict = {"credential_id": str(credential_id),
-                        "order_details": json.dumps(order_details)}
+                        "order_params": order_details}
         print(f"request_dict : {request_dict}")
 
-        response = requests.post(url=orders_url + "modify_order", params=request_dict)
+        response = requests.post(url=orders_url + "modify_order", json=request_dict)
         print("******** Order Placement Response *********")
         print(response.json())
         return response.json()
