@@ -943,19 +943,19 @@ def create_mt_report(trade_report, initial_deposit, file_name, logs_coll):
 
         mt_dict['total_trades'] = len(report_df)
 
-        signal_cnts = report_df['trade_type'].value_counts().to_dict()
+        signal_cnts = report_df['position_type'].value_counts().to_dict()
 
         if "LONG" not in signal_cnts:
             signal_cnts['LONG'] = 0
             long_pos_win = 0
         else:
-            long_pos_win = round((len(report_df[report_df['trade_type'] == "LONG"][report_df['pnl'] > 0]) / len(report_df) * 100), 2)
+            long_pos_win = round((len(report_df[report_df['position_type'] == "LONG"][report_df['pnl'] > 0]) / len(report_df) * 100), 2)
 
         if "SHORT" not in signal_cnts:
             signal_cnts['SHORT'] = 0
             short_pos_win = 0
         else:
-            short_pos_win = round((len(report_df[report_df['trade_type'] == "SHORT"][report_df['pnl'] > 0]) / len(report_df) * 100), 2)
+            short_pos_win = round((len(report_df[report_df['position_type'] == "SHORT"][report_df['pnl'] > 0]) / len(report_df) * 100), 2)
 
         # # Short Position (Won%)
         mt_dict['short_position'] = signal_cnts['SHORT']
@@ -1228,24 +1228,24 @@ def get_lot_size(stocks_li, exchange='NSE', segment='future', kite_api_key=None,
     return lot_size_dict
 
 
-def near_value(trade_type, operation, current_value, near_pct, file_name, logs_coll):
+def near_value(position_type, operation, current_value, near_pct, file_name, logs_coll):
     value = current_value
     try:
         near_pct /= 100
-        if trade_type == 'LONG':
+        if position_type == 'LONG':
             if operation == 'ENTRY':
                 value = current_value * (1 + near_pct)
             elif operation == 'EXIT':
                 value = current_value * (1 - near_pct)
 
-        elif trade_type == 'SHORT':
+        elif position_type == 'SHORT':
             if operation == 'ENTRY':
                 value = current_value * (1 - near_pct)
             elif operation == 'EXIT':
                 value = current_value * (1 + near_pct)
         else:
             value = current_value
-            log_message = f"trade type does not match with 'LONG' or 'SHORT'"
+            log_message = f"position_type does not match with 'LONG' or 'SHORT'"
             mg_insert_log(logs_coll, file_name, 'ERROR', log_message)
     except Exception as e:
         log_message = f"Exception in finding near value.\nReturning same value as given\n{e}\n"
@@ -1256,13 +1256,13 @@ def near_value(trade_type, operation, current_value, near_pct, file_name, logs_c
     return value
 
 
-def get_pnl(trade_type, entry_p, exit_p, lot_size, file_name, logs_coll):
+def get_pnl(position_type, entry_p, exit_p, lot_size, file_name, logs_coll):
     try:
-        if trade_type == 'LONG':
+        if position_type == 'LONG':
             points_gain = (exit_p - entry_p)
             pnl = points_gain * lot_size
 
-        elif trade_type == 'SHORT':
+        elif position_type == 'SHORT':
             points_gain = (entry_p - exit_p)
             pnl = points_gain * lot_size
 
@@ -1336,8 +1336,8 @@ def calculate_distribution(price, lot_sizes, investment_amount):
 def fetch_available_funds(credential_id):
     """Function to fetch current available funds in the account"""
     try:
-        print("***** Fetching Available Funds for : {} *****".format(credential_id))
-        response = requests.get(orders_url+"get_broker_fund?credential_id={}".format(credential_id))
+        print(f"***** Fetching Available Funds for : {credential_id} *****")
+        response = requests.post(orders_url+"get_broker_fund", json={"credential_id": credential_id})
         response_dict = response.json()
         if response_dict["status"] == "success" and response_dict["message"] == "Fund Found":
             fund_available = response_dict["data"]["net_balance"]
@@ -1384,7 +1384,7 @@ def send_order_alert(alert_dict):
         pass
 
 
-def calculate_brokerage(buy_price, sell_price, quantity, broker="zerodha", market_type="options", order_type="MARKET", lot_size=100, trade_type="LONG"):
+def calculate_brokerage(buy_price, sell_price, quantity, broker="zerodha", market_type="options", order_type="MARKET", lot_size=100, position_type="LONG"):
     """Function to calculate brokerage"""
     try:
         if broker in ["zerodha", "dhan", "icici direct"]:
@@ -1505,7 +1505,7 @@ def calculate_brokerage(buy_price, sell_price, quantity, broker="zerodha", marke
 
         elif broker == "binance":
             fee_rates = {
-                "equity": {"maker": 0.001, "taker": 0.001},
+                "spot": {"maker": 0.001, "taker": 0.001},
                 "futures": {"maker": 0.0002, "taker": 0.0004}
             }
 
@@ -1513,11 +1513,11 @@ def calculate_brokerage(buy_price, sell_price, quantity, broker="zerodha", marke
             fee_rate = fee_rates[market_type][m_t]
 
             # Calculate position size (margin * leverage)
-            entry_price = buy_price if trade_type.upper() == "LONG" else sell_price
+            entry_price = buy_price if position_type.upper() == "LONG" else sell_price
             position_size = quantity * entry_price
 
             # Calculate gross PnL
-            if trade_type.upper() == "SHORT":
+            if position_type.upper() == "SHORT":
                 gross_profit = (buy_price - sell_price) * quantity
             else:
                 gross_profit = (sell_price - buy_price) * quantity
@@ -1751,7 +1751,7 @@ def generate_mt_report(report_df, pnl_column='net_pnl'):
         out_dict['relative_drawdown'] = rel_drawdown
         out_dict['relative_drawdown%'] = (rel_drawdown / max_value) * 100
 
-        signal_cnts = report_df['trade_type'].value_counts().to_dict()
+        signal_cnts = report_df['position_type'].value_counts().to_dict()
 
         if 'SHORT' not in signal_cnts:
             signal_cnts['SHORT'] = 0
@@ -1759,8 +1759,8 @@ def generate_mt_report(report_df, pnl_column='net_pnl'):
         if 'LONG' not in signal_cnts:
             signal_cnts['LONG'] = 0
 
-        _short_pos_win = 0 if "SHORT" not in signal_cnts else round((len(report_df[report_df['trade_type'] == "SHORT"][report_df[pnl_column] > 0]) / len(report_df) * 100), 2)
-        _long_pos_win = 0 if "LONG" not in signal_cnts else round((len(report_df[report_df['trade_type'] == "LONG"][report_df[pnl_column] > 0]) / len(report_df) * 100), 2)
+        _short_pos_win = 0 if "SHORT" not in signal_cnts else round((len(report_df[report_df['position_type'] == "SHORT"][report_df[pnl_column] > 0]) / len(report_df) * 100), 2)
+        _long_pos_win = 0 if "LONG" not in signal_cnts else round((len(report_df[report_df['position_type'] == "LONG"][report_df[pnl_column] > 0]) / len(report_df) * 100), 2)
 
         # Short Position
         try:
@@ -1874,31 +1874,49 @@ def calculate_entry_quantity(investment, unit_price):
 
 def calculate_exit_quantity(total_quantity, target_split, sl_split):
     """ Function to generate accurate quantity for order processing """
-
     try:
         quantity_dict = {}
 
-        # Doing Manipulations for Targets
-        t_quantity = [int(total_quantity * i) for i in list(target_split.values())]
-        q_diff = total_quantity - sum(t_quantity)
-        if q_diff > 0:
-            t_quantity[0] += q_diff
+        if isinstance(total_quantity, int):
+            t_quantity = [int(total_quantity * i) for i in list(target_split.values())]
+            sl_quantity = [int(total_quantity) * i for i in list(sl_split.values())]
 
-        for indx, q in enumerate(target_split.keys()):
-            quantity_dict[q] = t_quantity[indx]
+            t_diff = total_quantity - sum(t_quantity)
+            if t_diff > 0:
+                t_quantity[0] += t_diff
 
-        # Doing Manipulations for Stop-Loss
-        sl_quantity = [int(total_quantity * i) for i in list(sl_split.values())]
-        q_diff = total_quantity - sum(sl_quantity)
-        if q_diff > 0:
-            sl_quantity[0] += q_diff
-        for indx, q in enumerate(sl_split.keys()):
-            quantity_dict[q] = sl_quantity[indx]
+            for indx, key in enumerate(target_split.keys()):
+                quantity_dict[key] = int(t_quantity[indx])
+
+            sl_diff = total_quantity - sum(sl_quantity)
+            if sl_diff > 0:
+                sl_quantity[0] += sl_diff
+
+            for indx, key in enumerate(sl_split.keys()):
+                quantity_dict[key] = int(sl_quantity[indx])
+
+        else:
+            t_quantity = [total_quantity * i for i in list(target_split.values())]
+            sl_quantity = [total_quantity * i for i in list(sl_split.values())]
+
+            t_diff = total_quantity - sum(t_quantity)
+            if t_diff > 0:
+                t_quantity[0] += t_diff
+
+            for indx, key in enumerate(target_split.keys()):
+                quantity_dict[key] = float(t_quantity[indx])
+
+            sl_diff = total_quantity - sum(sl_quantity)
+            if sl_diff > 0:
+                sl_quantity[0] += sl_diff
+
+            for indx, key in enumerate(sl_split.keys()):
+                quantity_dict[key] = float(sl_quantity[indx])
 
         return quantity_dict
 
     except Exception as e:
-        print(f"Exception in Generate Order Quantity : {e}")
+        print(f"Exception in Generate Exit Quantity : {e}")
         pass
 
 
